commit 0d12bff: Support i386 with optimizations

GitHub noreply at github.com
Fri Oct 22 18:56:04 UTC 2021


Author: xtkoba
Date: 2021-10-13 16:00:06 +0900
URL: https://github.com/rspamd/rspamd/commit/0d12bff1becdc78bbeacb61643eb9b722b6d394e (refs/pull/3934/head)

Support i386 with optimizations

---
 cmake/ArchDep.cmake | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/cmake/ArchDep.cmake b/cmake/ArchDep.cmake
index 71f2422ca..8271709b6 100644
--- a/cmake/ArchDep.cmake
+++ b/cmake/ArchDep.cmake
@@ -16,8 +16,8 @@ SET(ASM_CODE "
 	")
 ASM_OP(HAVE_DOLLARMACRO "dollar macro convention")
 
-# For now we support only x86_64 architecture with optimizations
-IF("${ARCH}" STREQUAL "x86_64")
+# For now we support only x86_64/i386 architecture with optimizations
+IF("${ARCH}" STREQUAL "x86_64" OR "${ARCH}" STREQUAL "i386")
     IF(NOT HAVE_SLASHMACRO AND NOT HAVE_DOLLARMACRO)
         MESSAGE(FATAL_ERROR "Your assembler cannot compile macros, please check your CMakeFiles/CMakeError.log")
     ENDIF()
@@ -99,4 +99,4 @@ IF ("${ARCH}" STREQUAL "x86_64")
     ELSEIF((CMAKE_C_COMPILER_ID MATCHES "MSVC"))
         ADD_COMPILE_OPTIONS(/arch:SSE2)
     ENDIF()
-ENDIF()
\ No newline at end of file
+ENDIF()


More information about the Commits mailing list